@@ -5,9 +5,11 @@
 
 from .base import db_session
 
-from .base import Base
+from .base import SkiplyBase
 
+from .associationContractService import AssociationContractService
 from .card import Card
+from .contract import Contract
 from .device import Device
 from .entity import Entity
 from .eventLog import EventLog
@@ -18,4 +20,5 @@ from .installInst import InstallationInstruction
 from .keyboard import Keyboard
 from .network import Network
 from .question import Question
+from .service import Service
 from .step import Step
\ No newline at end of file
