@@ -10,7 +10,7 @@ import os
 
 from sqlalchemy import create_engine
 from sqlalchemy.orm import scoped_session, sessionmaker
-from sqlalchemy.ext.declarative import declared_attr, declarative_base
+from sqlalchemy.ext.declarative import declared_attr, as_declarative
 
 from sqlalchemy import Column, Integer
 
@@ -18,13 +18,11 @@ logging.info(os.environ['SQLALCHEMY_DATABASE_URI'])
 SQLALCHEMY_DATABASE_URI = os.environ['SQLALCHEMY_DATABASE_URI']
 logging.info(SQLALCHEMY_DATABASE_URI)
 
-engine = create_engine(SQLALCHEMY_DATABASE_URI)
-db_session = scoped_session(sessionmaker(autocommit=False,autoflush=False,bind=engine))
+engine = create_engine(SQLALCHEMY_DATABASE_URI, echo=True, pool_recycle=280, pool_size=10) # pool_size/overflow
+db_session = sessionmaker(autocommit=False, autoflush=False, bind=engine)
 
+@as_declarative()
 class SkiplyBase(object):
     @declared_attr
     def __tablename__(cls):
-        return cls.__name__.lower()
-
-Base = declarative_base(cls=SkiplyBase)
-Base.query = db_session.query_property()
\ No newline at end of file
+        return cls.__name__.lower()
\ No newline at end of file
