@@ -6,14 +6,14 @@
 from __future__ import unicode_literals
 
 
-from .base import db_session, Base, SkiplyBase
+from .base import db_session, SkiplyBase, SkiplyBase
 
 from sqlalchemy import Boolean, Column, DateTime, ForeignKey, Integer, String, JSON
 
 import datetime
 
 
-class Card(Base):
+class Card(SkiplyBase):
     ''' Event Log '''
     __tablename__ = 'so_cards'
 
@@ -27,13 +27,23 @@ class Card(Base):
     device_type = Column('device_type', String(100))
 
     def __init__(self, skiply_id, sigfox_id, dev_uid, device_type=None):
+        self.device_skiply_id =skiply_id
+        
         self.skiply_id = skiply_id
-        self.sigfox_id = sigfox_id
         self.dev_uid = dev_uid
         self.device_type = device_type
 
     def __repr__(self):
-        return '<Cards %r>' % (self.skiply_id)
+        return '<Cards %r>' % (self.device_skiply_id)
 
-def getCard(device_id):
-    return db_session.query(Card).filter(Card.device_skiply_id == device_id).first()
\ No newline at end of file
+def get_card(device_id):
+    session = db_session()
+    try:
+        results =  session.query(Card).filter(Card.device_skiply_id == device_id).first()
+    except:
+        print("DB Request get_card(device_id) Failed")
+        results=None
+    finally:
+        session.close()
+
+    return results
\ No newline at end of file
