@@ -6,12 +6,12 @@
 from __future__ import unicode_literals
 
 
-from .base import db_session, Base, SkiplyBase
+from .base import db_session, SkiplyBase
 
 from sqlalchemy import Boolean, Column, DateTime, ForeignKey, Integer, String
 
 
-class Group(Base):
+class Group(SkiplyBase):
     ''' Device '''
     __tablename__ = 'so_groupe'
     
@@ -43,7 +43,25 @@ class Group(Base):
         return '<Group %r>' % (self.group_label)
 
 def get_group(group_id):
-    return db_session.query(Group).filter(Group.id == group_id).first()
+    session = db_session()
+    try:
+        results = session.query(Group).filter(Group.id == group_id).first()
+    except:
+        print("DB Request get_group(group_id) Failed")
+        results=None
+    finally:
+        session.close()
+
+    return results
 
 def get_groups_of_entity(entity_id):
-    return db_session.query(Group).filter(Group.entity_id == entity_id).all()
\ No newline at end of file
+    session = db_session()
+    try:
+        results = session.query(Group).filter(Group.entity_id == entity_id).all()
+    except:
+        print("DB Request get_groups_of_entity(entity_id) Failed")
+        results=None
+    finally:
+        session.close()
+
+    return results
\ No newline at end of file
