@@ -6,12 +6,12 @@
 from __future__ import unicode_literals
 
 
-from .base import db_session, Base, SkiplyBase
+from .base import db_session, SkiplyBase
 
 from sqlalchemy import Boolean, Column, DateTime, ForeignKey, Integer, String
 
 
-class Keyboard(Base):
+class Keyboard(SkiplyBase):
     ''' Device '''
     __tablename__ = 'so_frontage'
     
@@ -28,4 +28,13 @@ class Keyboard(Base):
         return '<Keyboard %r>' % (self.keyboard_label)
 
 def get_keyboard(keyboard_id):
-    return db_session.query(Keyboard).filter(Keyboard.id == keyboard_id).first()
\ No newline at end of file
+    session = db_session()
+    try:
+        results = session.query(Keyboard).filter(Keyboard.id == keyboard_id).first()
+    except:
+        print("DB Request get_keyboard(keyboard_id) Failed")
+        results = None
+    finally:
+        session.close()
+
+    return results
\ No newline at end of file
