@@ -6,12 +6,12 @@
 from __future__ import unicode_literals
 
 
-from .base import db_session, Base, SkiplyBase
+from .base import db_session, SkiplyBase
 
 from sqlalchemy import Boolean, Column, DateTime, ForeignKey, Integer, String
 
 
-class Network(Base):
+class Network(SkiplyBase):
     ''' Device '''
     __tablename__ = 'so_network'
     
@@ -35,4 +35,25 @@ class Network(Base):
         return '<Network %r>' % (self.network_label)
 
 def get_network(network_id):
-    return db_session.query(Network).filter(Network.id == network_id).first()
\ No newline at end of file
+    session = db_session()
+    try:
+        results = session.query(Network).filter(Network.id == network_id).first()
+    except:
+        print("DB Request get_network(network_id) Failed")
+        results = None
+    finally:
+        session.close()
+
+    return results
+
+def get_networks():
+    session = db_session()
+    try:
+        results = session.query(Network).all()
+    except:
+        print("DB Request get_networks() Failed")
+        results = None
+    finally:
+        session.close()
+
+    return results
\ No newline at end of file
