@@ -6,12 +6,12 @@
 from __future__ import unicode_literals
 
 
-from .base import db_session, Base, SkiplyBase
+from .base import db_session, SkiplyBase
 
 from sqlalchemy import Boolean, Column, DateTime, ForeignKey, Integer, String
 
 
-class Question(Base):
+class Question(SkiplyBase):
     ''' Device '''
     __tablename__ = 'so_question'
     
@@ -33,7 +33,25 @@ class Question(Base):
         return '<Question %r>' % (self.question_label)
 
 def get_question(question_id):
-    return db_session.query(Question).filter(Question.id == question_id).first()
+    session = db_session()
+    try:
+        results = session.query(Question).filter(Question.id == question_id).first()
+    except:
+        print("DB Request get_question(question_id) Failed")
+        results = None
+    finally:
+        session.close()
+
+    return results
 
 def get_questions_of_entity(entity_id):
-    return db_session.query(Question).filter(Question.entity_id == entity_id).all()
\ No newline at end of file
+    session = db_session()
+    try:
+        results = session.query(Question).filter(Question.entity_id == entity_id).all()
+    except:
+        print("DB Request get_questions_of_entity(entity_id) Failed")
+        results = None
+    finally:
+        session.close()
+
+    return results
\ No newline at end of file
