@@ -6,14 +6,14 @@
 from __future__ import unicode_literals
 
 
-from .base import db_session, Base, SkiplyBase
+from .base import db_session, SkiplyBase
 
 from sqlalchemy import Boolean, Column, DateTime, ForeignKey, Integer, String, JSON
 
 import datetime, json
 
 
-class Step(Base):
+class Step(SkiplyBase):
     ''' Event Log '''
     __tablename__ = 'i_steps'
 
@@ -54,10 +54,37 @@ class Step(Base):
 
 
 def get_steps(install_inst_id):
-    return db_session.query(Step).filter(Step.install_inst_id==install_inst_id).order_by(Step.step_seq_nb).all()
+    session = db_session()
+    try:
+        results = session.query(Step).filter(Step.install_inst_id==install_inst_id).order_by(Step.step_seq_nb).all()
+    except:
+        print("DB Request get_steps(install_inst_id) Failed")
+        results = None
+    finally:
+        session.close()
+
+    return results
 
 def get_steps_device(install_inst_id):
-    return db_session.query(Step).filter(Step.install_inst_id==install_inst_id, Step.step_seq_device==1).order_by(Step.step_seq_nb).all()
+    session = db_session()
+    try:
+        results = session.query(Step).filter(Step.install_inst_id==install_inst_id, Step.step_seq_device==1).order_by(Step.step_seq_nb).all()
+    except:
+        print("DB Request get_steps_device(install_inst_id) Failed")
+        results = None
+    finally:
+        session.close()
+
+    return results
 
 def get_steps_group(install_inst_id):
-    return db_session.query(Step).filter(Step.install_inst_id==install_inst_id, Step.step_seq_group==1).order_by(Step.step_seq_nb).all()
\ No newline at end of file
+    session = db_session()
+    try:
+        results = session.query(Step).filter(Step.install_inst_id==install_inst_id, Step.step_seq_group==1).order_by(Step.step_seq_nb).all()
+    except:
+        print("DB Request get_steps_group(install_inst_id) Failed")
+        results = None
+    finally:
+        session.close()
+
+    return results
\ No newline at end of file
